#!/bin/sh
# Bryant Hansen

ME="$(basename "$0")"
USAGE="$ME"

DebugMessage() {
    local LOG_RECORD_HEADER="`date "+%Y%m%d_%H%M%S"` (${ME}):"
    echo "${LOG_RECORD_HEADER} $*" >&2
}

CONF_FILE="/etc/logfile_uploader.conf"
if [[ ! -f "$CONF_FILE" ]] ; then
    DebugMessage "$ME ERROR: configuration file $CONF_FILE not found."
    DebugMessage "Exiting abnormally."
    exit 2
fi
. "$CONF_FILE"

USER=$(get_mac_address.sh)
if [[ ! "$USER" ]] ; then
    DebugMessage "$ME ERROR: failed to get MAC address (used for username login to server)"
    DebugMessage "verify installation failure"
    exit 8
fi
if [[ ! "${USER%%[0-9]*}" ]] ; then
    DebugMessage "$ME WARNING: MAC address does not begin with a letter.  Modifying registration name from $USER to m_${USER}"
    USER="m_${USER}"
fi

PUBKEYFILE=/home/root/.ssh/${USER}.key.pub

# verify that the key file exists
if [[ ! -f "$PUBKEYFILE" ]] ; then
        DebugMessage "$ME ERROR: public key file $PUBKEYFILE not found."
        DebugMessage "registration failure"
        exit 5
fi

( echo $USER ; cat $PUBKEYFILE ) | nc $SERVER $REGISTRATION_PORT
